/*
 * SendManyTestKuma.java
 *
 * Copyright 2014 the curewallet.org.
 * http://www.curewallet.org/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */

package org.curewallet.lib.api;

import static org.junit.Assert.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

import org.curewallet.lib.TestResources;
import org.curewallet.lib.api.GetTransaction;
import org.curewallet.lib.api.SendMany;
import org.curewallet.lib.api.WalletLock;
import org.curewallet.lib.api.WalletPassphrase;
import org.curewallet.lib.api.impl.DefaultCoinAPIFactory;
import org.curewallet.lib.api.result.Details;
import org.curewallet.lib.api.result.GetTransactionResult;
import org.curewallet.lib.api.result.SendManyResult;
import org.curewallet.lib.jsonrpc.JsonRPCClient;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import org.seasar.framework.container.S2Container;
import org.seasar.framework.container.factory.S2ContainerFactory;

/**
 * 
 * 
 * @version 
 * @author Nezumi Kozo
 * @since 
 */
public class SendManyTestKuma {

	static S2Container container = null;
	static DefaultCoinAPIFactory factory = null;
	static JsonRPCClient jsonRPC = null;
	static TestResources resources = null;
	
	/**
	 * 
	 * @throws java.lang.Exception
	 * @since 
	 */
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		container = S2ContainerFactory.create("test-kumacoin.dicon");
		jsonRPC = (JsonRPCClient)container.getComponent(JsonRPCClient.class);
		factory = DefaultCoinAPIFactory.newInstance();
		resources = (TestResources)container.getComponent(TestResources.class);
	}

	/**
	 * @throws java.lang.Exception
	 * @since 
	 */
	@AfterClass
	public static void tearDownAfterClass() throws Exception {
		jsonRPC.close();
	}

	/**
	 * @throws java.lang.Exception
	 * @since 
	 */
	@Before
	public void setUp() throws Exception {
		if (resources.isWalletEncry()) {
			WalletPassphrase unlock = (WalletPassphrase)container.getComponent(WalletPassphrase.class);
			unlock.call(jsonRPC, resources.getPassphrase(), 100L);
		}
	}

	/**
	 * @throws java.lang.Exception
	 * @since 
	 */
	@After
	public void tearDown() throws Exception {
		if (resources.isWalletEncry()) {
			WalletLock lock = (WalletLock)container.getComponent(WalletLock.class);
			lock.call(jsonRPC);
		}
	}

	
	/**
	 * Test
	 * SendMany.call(JsonRPCClient jsonRPCClient, String acount, Map<String, BigDecimal> addressAmount)
	 * 
	 * 【テスト仕様】
	 * 送金し、送金処理がされていることを確認する。
	 * 
	 * 【確認事項】
	 * ・送金数が一致していること。
	 * ・金額が一致していること。
	 * 
	 * @throws Exception
	 * @since 1.0
	 */
	@Test
	public void test1() throws Exception {

		if (resources.isTestSendMany_test1() == false) {
			System.out.println("test skip SendManyTestKuma.isTestSendMany_test1");
			return;
		}

		SendMany obj = (SendMany)container.getComponent(SendMany.class);
		Map<String, BigDecimal> map = new HashMap<String, BigDecimal>();
		map.put(resources.getTestSendMany_address1(), new BigDecimal("0.01"));
		map.put(resources.getTestSendMany_address2(), new BigDecimal("0.03"));
		SendManyResult result = obj.call(jsonRPC, resources.getTestSendMany_fromAccount(), map);

		assertNotNull(result.getTransactionId());

		GetTransaction obj2 = (GetTransaction)container.getComponent(GetTransaction.class);
		GetTransactionResult result2 = obj2.call(jsonRPC, result.getTransactionId());

		int sendCount = 0;
		for (int i = 0; i < result2.getDetails().length; i++) {
			Details details = result2.getDetails()[i];
			if ("send".equals(details.getCategory())) {
				if (resources.getTestSendMany_address1().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.01000000"),details.getAmount());
				} else if (resources.getTestSendMany_address2().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.03000000"),details.getAmount());
				} 
				sendCount++;
			}
		}
		assertEquals(2, sendCount);
		assertEquals(null,result2.getComment());
	}

	
	/**
	 * Test
	 * SendMany.call(JsonRPCClient jsonRPCClient, String acount, Map<String, BigDecimal> addressAmount, Integer minConf)
	 * 
	 * 【テスト仕様】
	 * 送金し、送金処理がされていることを確認する。
	 * 
	 * 【確認事項】
	 * ・送金数が一致していること。
	 * ・金額が一致していること。
	 * 
	 * @throws Exception
	 * @since 1.0
	 */
	@Test
	public void test2() throws Exception {
		if (resources.isTestSendMany_test2() == false) {
			System.out.println("test skip SendManyTestKuma.isTestSendMany_test2");
			return;
		}

		SendMany obj = (SendMany)container.getComponent(SendMany.class);
		Map<String, BigDecimal> map = new HashMap<String, BigDecimal>();
		map.put(resources.getTestSendMany_address1(), new BigDecimal("0.01"));
		map.put(resources.getTestSendMany_address2(), new BigDecimal("0.03"));
		SendManyResult result = obj.call(jsonRPC, resources.getTestSendMany_fromAccount(), map, 22L);

		assertNotNull(result.getTransactionId());

		GetTransaction obj2 = (GetTransaction)container.getComponent(GetTransaction.class);
		GetTransactionResult result2 = obj2.call(jsonRPC, result.getTransactionId());

		int sendCount = 0;
		for (int i = 0; i < result2.getDetails().length; i++) {
			Details details = result2.getDetails()[i];
			if ("send".equals(details.getCategory())) {
				if (resources.getTestSendMany_address1().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.01000000"),details.getAmount());
				} else if (resources.getTestSendMany_address2().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.03000000"),details.getAmount());
				} 
				sendCount++;
			}
		}
		assertEquals(2, sendCount);
		assertEquals(null,result2.getComment());

	}

	/**
	 * Test
	 * SendMany.call(JsonRPCClient jsonRPCClient, String acount, Map<String, BigDecimal> addressAmount, String comment)
	 * 
	 * 【テスト仕様】
	 * 送金し、送金処理がされていることを確認する。
	 * 
	 * 【確認事項】
	 * ・送金数が一致していること。
	 * ・金額が一致していること。
	 * ・コメントが一致していること。
	 * 
	 * @throws Exception
	 * @since 1.0
	 */
	@Test
	public void test3() throws Exception {
		if (resources.isTestSendMany_test3() == false) {
			System.out.println("test skip SendManyTestKuma.isTestSendMany_test3");
			return;
		}

		SendMany obj = (SendMany)container.getComponent(SendMany.class);
		Map<String, BigDecimal> map = new HashMap<String, BigDecimal>();
		map.put(resources.getTestSendMany_address1(), new BigDecimal("0.01"));
		map.put(resources.getTestSendMany_address2(), new BigDecimal("0.03"));
		SendManyResult result = obj.call(jsonRPC, resources.getTestSendMany_fromAccount(), map, "test3");

		assertNotNull(result.getTransactionId());

		GetTransaction obj2 = (GetTransaction)container.getComponent(GetTransaction.class);
		GetTransactionResult result2 = obj2.call(jsonRPC, result.getTransactionId());

		int sendCount = 0;
		for (int i = 0; i < result2.getDetails().length; i++) {
			Details details = result2.getDetails()[i];
			if ("send".equals(details.getCategory())) {
				if (resources.getTestSendMany_address1().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.01000000"),details.getAmount());
				} else if (resources.getTestSendMany_address2().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.03000000"),details.getAmount());
				} 
				sendCount++;
			}
		}
		assertEquals(2, sendCount);
		assertEquals("test3",result2.getComment());
	}

	/**
	 * Test
	 * SendMany.call(JsonRPCClient jsonRPCClient, String acount, Map<String, BigDecimal> addressAmount, Integer minConf, String comment)
	 * 
	 * 【テスト仕様】
	 * 送金し、送金処理がされていることを確認する。
	 * 
	 * 【確認事項】
	 * ・送金数が一致していること。
	 * ・金額が一致していること。
	 * ・コメントが一致していること。
	 * 
	 * @throws Exception
	 * @since 1.0
	 */
	@Test
	public void test4() throws Exception {
		if (resources.isTestSendMany_test4() == false) {
			System.out.println("test skip SendManyTestKuma.isTestSendMany_test4");
			return;
		}

		SendMany obj = (SendMany)container.getComponent(SendMany.class);
		Map<String, BigDecimal> map = new HashMap<String, BigDecimal>();
		map.put(resources.getTestSendMany_address1(), new BigDecimal("0.01"));
		map.put(resources.getTestSendMany_address2(), new BigDecimal("0.03"));
		SendManyResult result = obj.call(jsonRPC, resources.getTestSendMany_fromAccount(), map, 2L, "test4");

		assertNotNull(result.getTransactionId());

		GetTransaction obj2 = (GetTransaction)container.getComponent(GetTransaction.class);
		GetTransactionResult result2 = obj2.call(jsonRPC, result.getTransactionId());

		int sendCount = 0;
		for (int i = 0; i < result2.getDetails().length; i++) {
			Details details = result2.getDetails()[i];
			if ("send".equals(details.getCategory())) {
				if (resources.getTestSendMany_address1().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.01000000"),details.getAmount());
				} else if (resources.getTestSendMany_address2().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.03000000"),details.getAmount());
				} 
				sendCount++;
			}
		}
		assertEquals(2, sendCount);
		assertEquals("test4",result2.getComment());

	}
	
	

	
	/**
	 * Test Factory
	 * 
	 * @throws Exception
	 * @since 1.0
	 */
	@Test
	public void testFactory() throws Exception {

		if (resources.isTestSendMany_testFactory() == false) {
			System.out.println("test skip SendManyTestKuma.isTestSendMany_testFactory");
			return;
		}

		SendMany obj = factory.getSendMany();
		Map<String, BigDecimal> map = new HashMap<String, BigDecimal>();
		map.put(resources.getTestSendMany_address1(), new BigDecimal("0.01"));
		map.put(resources.getTestSendMany_address2(), new BigDecimal("0.03"));
		SendManyResult result = obj.call(jsonRPC, resources.getTestSendMany_fromAccount(), map);

		assertNotNull(result.getTransactionId());

		GetTransaction obj2 = (GetTransaction)container.getComponent(GetTransaction.class);
		GetTransactionResult result2 = obj2.call(jsonRPC, result.getTransactionId());

		int sendCount = 0;
		for (int i = 0; i < result2.getDetails().length; i++) {
			Details details = result2.getDetails()[i];
			if ("send".equals(details.getCategory())) {
				if (resources.getTestSendMany_address1().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.01000000"),details.getAmount());
				} else if (resources.getTestSendMany_address2().equals(details.getAddress())) {
					assertEquals(new BigDecimal("-0.03000000"),details.getAmount());
				} 
				sendCount++;
			}
		}
		assertEquals(2, sendCount);
		assertEquals(null,result2.getComment());
	}
}
